@@ -3,10 +3,11 @@ OC.L10N.register(
     {
     "Notes" : "Notes",
     "Error" : "Памылка",
-    "Today" : "Today",
-    "Yesterday" : "Учора",
+    "Share" : "Падзяліцца",
     "Rename" : "Rename",
     "Remove from favorites" : "Remove from favorites",
-    "Add to favorites" : "Add to favorites"
+    "Add to favorites" : "Add to favorites",
+    "Today" : "Today",
+    "Yesterday" : "Учора"
 },
 "nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
