@@ -11,8 +11,8 @@ OC.L10N.register(
     "Undo Delete" : "ביטול מחיקה",
     "Note recovered" : "הפתק שוחזר",
     "There are unsaved notes. Leaving the page will discard all changes!" : "ישנן הערות שלא נשמרו. יציאה מהעמוד תעלים את השינויים שערכת!",
-    "_Deleted {number} note_::_Deleted {number} notes_" : ["פתק אחד נמחק","{number} פתקים נמחקו","{number} פתקים נמחקו","{number} פתקים נמחקו"],
-    "_Recovered {number} note_::_Recovered {number} notes_" : ["פתק אחד שוחזר","{number} פתקים שוחזרו","{number} פתקים שוחזרו","{number} פתקים שוחזרו"],
+    "_Deleted {number} note_::_Deleted {number} notes_" : ["פתק אחד נמחק","{number} פתקים נמחקו","{number} פתקים נמחקו"],
+    "_Recovered {number} note_::_Recovered {number} notes_" : ["פתק אחד שוחזר","{number} פתקים שוחזרו","{number} פתקים שוחזרו"],
     "Write down your thoughts without any distractions." : "כתיבת המחשבות שלך ללא הסחות.",
     "Organize your notes in categories." : "ארגון הפתקים שלך בקטגוריות.",
     "Folder to store your notes" : "תיקייה לאחסון הפתקיות שלך",
@@ -73,4 +73,4 @@ OC.L10N.register(
     "Tasks" : "משימות",
     "Development Mode" : "מצב פיתוח"
 },
-"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: (n % 10 == 0 && n % 1 == 0 && n > 10) ? 2 : 3;");
+"nplurals=3; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: 2;");
