@@ -3,10 +3,11 @@ OC.L10N.register(
     {
     "Notes" : "Notes",
     "Error" : "﻿ತಪ್ಪಾಗಿದೆ",
-    "Today" : "Today",
-    "Rename" : "﻿ಮರುಹೆಸರಿಸು",
+    "Share" : "﻿ಹಂಚಿಕೊಳ್ಳಿ",
+    "Rename" : "Rename",
     "Remove from favorites" : "Remove from favorites",
     "Add to favorites" : "Add to favorites",
-    "Edit" : "ಸಂಪಾದಿಸು"
+    "Edit" : "ಸಂಪಾದಿಸು",
+    "Today" : "Today"
 },
 "nplurals=2; plural=(n > 1);");
