@@ -22,7 +22,7 @@ OC.L10N.register(
     "Action" : "Atzione",
     "Open in edit mode" : "Aberi in modalidade modìfica",
     "Open in preview mode" : "Aberi in modalidade anteprima",
-    "Insert image" : "Inserta·nche imàgine",
+    "Insert image" : "Inserta·nche immàgine",
     "All notes" : "Totu is notas",
     "Categories" : "Categorias",
     "No notes yet" : "Peruna nota ancora",
@@ -59,7 +59,7 @@ OC.L10N.register(
     "Note is locked." : "Sa nota est blocada.",
     "Insufficient storage." : "S'ispàtziu de archiviatzione non bastat.",
     "See JavaScript console and server log for details." : "Càstia sa consolla JavaScript e is registros de su serbidore pro is detàllios.",
-    "Updating settings has failed." : "Agiornamentu de is impostatziones faddidu.",
+    "Updating settings has failed." : "Errore in s'atualizatzione de sa cunfiguratzione.",
     "Fetching notes for dashboard has failed." : "Recùperu de is notas pro su pannellu de controllu faddidu.",
     "Fetching notes has failed." : "Recùperu de is notas faddidu.",
     "Fetching note {id} has failed." : "Recùperu nota {id} faddidu.",
