@@ -60,14 +60,14 @@ class Note {
 		$excerpt = trim($this->noteUtil->stripMarkdown($this->getContent()));
 		$title = $this->getTitle();
 		if (!empty($title)) {
-			$length = mb_strlen($title, "utf-8");
+			$length = mb_strlen($title, 'utf-8');
 			if (strncasecmp($excerpt, $title, $length) === 0) {
-				$excerpt = mb_substr($excerpt, $length, null, "utf-8");
+				$excerpt = mb_substr($excerpt, $length, null, 'utf-8');
 			}
 		}
 		$excerpt = trim($excerpt);
-		if (mb_strlen($excerpt, "utf-8") > $maxlen) {
-			$excerpt = mb_substr($excerpt, 0, $maxlen, "utf-8") . '…';
+		if (mb_strlen($excerpt, 'utf-8') > $maxlen) {
+			$excerpt = mb_substr($excerpt, 0, $maxlen, 'utf-8') . '…';
 		}
 		return str_replace("\n", "\u{2003}", $excerpt);
 	}
@@ -107,7 +107,7 @@ class Note {
 		}
 		$data['internalPath'] = $this->noteUtil->getPathForUser($this->file);
 		$data['shareTypes'] = $this->noteUtil->getShareTypes($this->file);
-		$data['isShared'] = (bool) count($data['shareTypes']);
+		$data['isShared'] = (bool)count($data['shareTypes']);
 		$data['error'] = false;
 		$data['errorType'] = '';
 		if (!in_array('content', $exclude)) {
